/**
* Breadcrumb Menu event handler
*/
function toggleBCDropdown($trigger, show)
{
	'use strict';

	if (!$trigger) {
		// Hide all dropdown menus, because there is no trigger (meaning a time-out)
		$('.breadcrumbs .zn-dropdown.open').each(function(){ zeina.dropdown(this, false) });
		return;
	}

	var options = $trigger.data('dropdown-options'),
		$parent =  $trigger.parent(),
        $zn_dropdown = $trigger.parentsUntil('.dropdown-contents'),
		visible = $parent.hasClass(options ? options.visibleClass : 'open'),
		crumb = options ? options.crumb : 'index';

        // Hide all other dropdown menus
		$trigger.parentsUntil('.zn-dropdown-menu').find('.zn-dropdown.open').not($zn_dropdown).each(function(){ 
            zeina.dropdown(this, false);
        });

	if (show && !visible) {
		// Show the menu
        zeina.dropdown($parent, true);
	} 
    else if (!(show && visible)) {
		// Hide & destroy a menu
        zeina.dropdown($parent, false);
		$('#breadcrumb-menu').find('#crumb-menu-' + crumb).remove();
	}

	// Prevent event propagation
	if (arguments.length > 0) {
		try {
			var e = arguments[0];
			e.preventDefault();
			e.stopPropagation();
		}
		catch (error) { }
	}
	return false;
}

function setupBCMenu()
{
	'use strict';

	var showTimer,
		hideTimer,
		touchTimer;

	$('.breadcrumb-item').each(function()
	{
		var $this = $(this);
		var $trigger = $this.find('a');

		// if a crumb doesn't have a link, do nothing
		if (!$trigger.length) { return; }

		// remove those annoying title tooltips
		$trigger.removeAttr('title');

		// find the link reference
		var forum_ref = $trigger.attr('data-navbar-reference'),
			forum_id = parseInt($trigger.parent().attr('data-forum-id')),
			crumb;

		if (forum_ref === 'index') {
			crumb = forum_ref;
		} else if (!isNaN(forum_id)) {
			crumb = forum_id;
		} else {
			return;
		}

		var ops = {
				direction: 'auto', // Direction of dropdown menu. Possible values: auto, left, right
				verticalDirection: 'auto', // Vertical direction. Possible values: auto, up, down
				visibleClass: 'open', // Class to add to parent item when dropdown is visible
				leftClass: 'dropdown-end', // Class to add to parent item when dropdown opens to left side
				rightClass: 'dropdown-start', // Class to add to parent item when dropdown opens to right side
				upClass: 'dropdown-top', // Class to add to parent item when dropdown opens above menu item
				downClass: 'dropdown-bottom', // Class to add to parent item when dropdown opens below menu item
				crumb: crumb
			};

		// assign data to the trigger element
        $trigger.parent().addClass('zn-dropdown no-scroll relative');
		$trigger.addClass('zn-dropdown-toggle');
		$trigger.data('dropdown-options', ops);
        
        let menu = $('#breadcrumb-menu');
        menu.find('.hidden').removeClass('hidden')
        menu.find('ul')
            .addClass('dropdown-contents')
            .find('.children a')
            .addClass('dropdown-item justify-between w-full')
            .each(function () {
                let sub_menu = $(this).parent().find('.dropdown-contents');
                if (sub_menu.length) {
                    $(this).addClass('zn-dropdown-toggle');
                    if (!$(this).find('svg').length) {
                        $(this).append('<svg xmlns="http://www.w3.org/2000/svg" width="12" height="16" viewBox="0 0 12 24"><defs><path id="weuiArrowOutlined0" fill="currentColor" d="m7.588 12.43l-1.061 1.06L.748 7.713a.996.996 0 0 1 0-1.413L6.527.52l1.06 1.06l-5.424 5.425z"/></defs><use fill-rule="evenodd" href="#weuiArrowOutlined0" transform="rotate(-180 5.02 9.505)"/></svg>');
                    }
                }
            });

        var $sub = menu.find('.dropdown-contents .children .dropdown-contents');

        $sub.each(function () {
            if (!$(this).parent().hasClass('zn-dropdown-menu')) {
                $(this).after('<div class="zn-dropdown-menu dropdown md:w-48 ">');
                $(this).parent().find('.zn-dropdown-menu').append($(this));
            }

            if (!$(this).parentsUntil('li').parent().hasClass('zn-dropdown')) {
                $(this).parentsUntil('li').parent().addClass('zn-dropdown sub-dropdown no-scroll relative')
            } 
        });
        
        let new_menu = menu.clone();
        new_menu.removeAttr('id');

        if (crumb) {
            new_menu = new_menu.find('#crumb-' + crumb).parent();
            new_menu.addClass('breadcrumb-menu-ext');
        }

        $trigger.after(new_menu);
	});

    // if the user has a touch-screen, don't open the crumb URL; open the menu instead
	if (isTouch) {
		$(document).on({
			'click' : function(event)
			{
				event.preventDefault();
			},
			'touchstart': function()
			{
				touchTimer = setTimeout(function() {
					clearTimeout(touchTimer);
					touchTimer = true;
				}, 300);
			},
			'touchend': function()
			{
				if (touchTimer === true) {
					location.href = $(this).attr('href');
				}
				clearTimeout(touchTimer);
			}
		}, '.breadcrumb-item a.zn-dropdown-toggle');
	}

	$(document).on({
		'mouseenter': function()
		{
			clearTimeout(hideTimer);

			showTimer = setTimeout(e => {
                if (window.innerWidth > 768)
				    toggleBCDropdown($(this), true);
			}, 400);
		},
		'mouseleave': function()
		{
			clearTimeout(showTimer);
		},
    'click': function (e) {
      let link = $(this).attr('href');

			if ($(this).hasClass('zn-dropdown-toggle'))
			{
				if (link && window.innerWidth > 768) {
					location.href = link;
				} else {
					e.preventDefault();
				}
			}
    }
	}, '.breadcrumb-item a');

	// assign listeners to determine if the user has moved away
	$('.breadcrumbs, #breadcrumb-menu').on({
		'mouseenter': function() {
			clearTimeout(hideTimer);
		},
		'mouseleave': function() {
			hideTimer = setTimeout(function() {
				clearTimeout(hideTimer);
                if (window.innerWidth > 768)
				    toggleBCDropdown(false, false);
			}, 700);
		}
	});

	// add fly-out trigger buttons for touch devices
	if (isTouch) {
		$('#breadcrumb-menu').addClass('touch-enabled');
	}
}

var isTouch;

$(function()
{
	'use strict';

	var $document = $(document);

	$document.one('touchstart.BCMenu mousemove.BCMenu', function(e){
		$document.off('.BCMenu');
		isTouch = (e.type === 'touchstart');
		setupBCMenu();
	});
});
